package sentio

import (
	"time"
)

type Market interface {
	Clock() Clock
	IsOpen() bool

	Connect(done chan struct{}) (chan MarketConnection, error)
	Subscribe(symbols ...string) error

	Account() (MarketAccount, error)
	MaxBudget() float64
	EnableLongLeverage() bool
	EnableShortLeverage() bool

	CreateOrder(opts OrderCreateOptions) error
	UpdateOrder(orderID string, opts OrderUpdateOptions) error
	CloseOrder(order Order, desiredPrice *float64) (float64, error)

	DeletePosition(symbol string) (float64, error)

	Order(orderID string, nested bool) (Order, error)
	Orders(criteria OrderListCriteria) ([]Order, error)
	Portfolio() (Portfolio, error)
	PortfolioHistory() ([]PortfolioRecord, error)
	Quotes() (map[string]Quote, error)
	HistoricalBars(interval time.Duration, from *time.Time) (map[string][]Bar, error)
}
